# utils_base.console.constants (auto generate by build_inits.py)

from utils_base.console.constants.COLOR_BACKGROUND import COLOR_BACKGROUND
from utils_base.console.constants.COLOR_FOREGROUND import COLOR_FOREGROUND
from utils_base.console.constants.COLOR_FORMAT import COLOR_FORMAT
from utils_base.console.constants.LEVEL_TO_STYLE import LEVEL_TO_STYLE
